| SpatialData | R Documentation |
This is a simulated epidemic data set of population size = 50 individuals that was generated using a distance-based SIR individual-level model (ILM) with power-law distance kernel. The model has no susceptible covariates and the infectivity rate is given by:
\lambda_{jt} = \alpha_{0} \sum_{i \in I_{t}}{d_{ij}^{-\beta}}
The infectious period is assumed to follow an exponential distribution with rate \lambda. The epidemic was simulated with the following parameter values: \alpha_{0} = 2.0, \beta = 3 and \delta = 2.
The data set file is an object of class "datagen" that has a list of type, kerneltype, epidat and location.
data(SpatialData)
An object of class “datagen” that contains the following:
The “SIR” compartmental framework.
The “distance” kernel function.
A matrix of the simulated epidemic with four columns as: the id numbers of individuals, removal times, infectious periods, and infection times.
A matrix of the XY coordinates of individuals.
A zero matrix of contact network.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.